@@ -28,13 +28,13 @@ Q_OBJECT
 public:
     static Animator* instance();
     
-    ~Animator();
+    ~Animator() override;
     void add(Animation*);
     
     void start();
     void stop();
     void restart();
-private slots:
+private Q_SLOTS:
     void tick();
 };
 
