@@ -16,7 +16,7 @@
 #include <QDomNode>
 #include <QTcpSocket>
 
-#define ADD_FIELD(msg, field) addField(#field, msg.field())
+#define ADD_FIELD(msg, field) addField(QStringLiteral(#field), msg.field())
 class MessageSender : public MessageVisitor
 {
     QDomDocument m_doc;
@@ -34,7 +34,7 @@ class MessageSender : public MessageVisitor
     template <typename Msg>
     void setType(const Msg&)
     {
-        QDomElement element = addField("msgtype", QString::number(Msg::MSGTYPE));
+        QDomElement element = addField(QStringLiteral("msgtype"), QString::number(Msg::MSGTYPE));
         // only useful for debugging, just add the name of the message type
         element.setAttribute(QLatin1String("type"), Msg::messageType());
     }
@@ -79,7 +79,7 @@ public:
         setType(msg);
         addField(QStringLiteral("fieldx"), QString::number(msg.move().x));
         addField(QStringLiteral("fieldy"), QString::number(msg.move().y));
-        addField(QStringLiteral("fieldstate"), msg.hit() ? "1" : "99");
+        addField(QStringLiteral("fieldstate"), msg.hit() ? QStringLiteral("1") : QStringLiteral("99"));
         if (msg.death()) {
             addField(QStringLiteral("death"), QStringLiteral("true"));
             addField(QStringLiteral("xstart"), QString::number(msg.start().x));
@@ -92,11 +92,11 @@ public:
     void visit(const GameOverMessage& msg) override
     {
         setType(msg);
-        foreach (const GameOverMessage::ShipInfo &ship, msg.ships()) {
+        for (const GameOverMessage::ShipInfo &ship : msg.ships()) {
             QStringList data;
             data << QString::number(ship.pos.x)
                  << QString::number(ship.pos.y)
-                 << (ship.direction == Ship::TOP_DOWN ? "0" : "1");
+                 << (ship.direction == Ship::TOP_DOWN ? QStringLiteral("0") : QStringLiteral("1"));
             addField(QStringLiteral("ship") + QString::number(ship.size), data.join( QLatin1String( " " )));
         }
     }
@@ -155,11 +155,11 @@ void Protocol::readMore()
         MessagePtr msg = parseMessage(m_buffer.left(pos));
         m_buffer.remove(0, pos);
         
-        emit received(msg);
+        Q_EMIT received(msg);
     }
 }
 
-#define DEF_ELEMENT(var) QString var = main.namedItem(#var).toElement().text()
+#define DEF_ELEMENT(var) QString var = main.namedItem(QStringLiteral(#var)).toElement().text()
 #define DEF_COORD(var, varx, vary) DEF_ELEMENT(varx); DEF_ELEMENT(vary); Coord var(varx.toInt(), vary.toInt());
 MessagePtr Protocol::parseMessage(const QString& xmlMessage)
 {
@@ -171,14 +171,14 @@ MessagePtr Protocol::parseMessage(const QString& xmlMessage)
     QDomElement main = doc.documentElement();
     if (main.tagName() != QLatin1String("kmessage"))
     {
-        emit parseError(QStringLiteral("Invalid parent tag"));
+        Q_EMIT parseError(QStringLiteral("Invalid parent tag"));
         return MessagePtr();
     }
     
     QDomElement msgtype = main.namedItem(QStringLiteral("msgtype")).toElement();
     if (msgtype.isNull())
     {
-        emit parseError(QStringLiteral("No message type"));
+        Q_EMIT parseError(QStringLiteral("No message type"));
         return MessagePtr();
     }
     
@@ -235,12 +235,12 @@ MessagePtr Protocol::parseMessage(const QString& xmlMessage)
                 QDomElement element = nodes.item(i).toElement();
                 if (!element.isNull() && element.tagName().startsWith(QLatin1String("ship"))) {
                     int size = element.tagName().midRef(4).toInt();
-                    QStringList data = element.text().split(' ');
+                    QStringList data = element.text().split(QLatin1Char(' '));
                     if (data.size() != 3) {
                         continue;
                     }
                     Coord pos(data[0].toInt(), data[1].toInt());
-                    Ship::Direction direction = data[2] == QChar('0')
+                    Ship::Direction direction = data[2] == QLatin1Char('0')
                         ? Ship::TOP_DOWN 
                         : Ship::LEFT_TO_RIGHT;
                     msg->addShip(pos, size, direction);
@@ -297,7 +297,7 @@ MessagePtr Protocol::parseMessage(const QString& xmlMessage)
             return MessagePtr(new GameOptionsMessage(adjacentShips, severalShips, battleShipsConfiguration));
         }
     default:
-        emit parseError(QStringLiteral("Unknown message type"));
+        Q_EMIT parseError(QStringLiteral("Unknown message type"));
         return MessagePtr();
     }
 }
@@ -327,6 +327,6 @@ void Protocol::sendNext()
 void Protocol::processDisconnection()
 {
     m_timer.stop();
-    emit disconnected();
+    Q_EMIT disconnected();
 }
 
