@@ -40,7 +40,7 @@ void StatsWidgetElement::paintEvent(QPaintEvent * /*ev*/)
 
 void StatsWidgetElement::setText(const QString &text)
 {
-    QString value = "<font size=\"5\">" + text + "</font>";
+    QString value = QLatin1String("<font size=\"5\">") + text + QLatin1String("</font>");
     m_text->setText(value);
 }
 
@@ -63,7 +63,7 @@ void StatsWidgetElement::setData(const QPixmap &icon, const QString &text)
 
 StatsWidget::StatsWidget(KBSRenderer *renderer, QWidget *parent)
 : QWidget(parent)
-, m_stats(0)
+, m_stats(nullptr)
 {
     m_elements[0] = new StatsWidgetElement(
         renderer->spritePixmap(QStringLiteral("water-impact"), QSize(32, 32)),
